@@ -6,7 +6,7 @@ sub _patch { *{$_[0]} = $_[1] }
 use strict;
 use warnings;
 
-our $VERSION = '0.02';
+our $VERSION = '0.04';
 $VERSION = eval $VERSION;
 
 use Carp ();
@@ -150,10 +150,10 @@ Currently the optional hashref only accepts one option, an initial value for L</
 
 =head2 arguments
 
-  my $args = $mock->argument;
-  my $args_second_time = $mock->argument(1);
+  my $args = $mock->arguments;
+  my $args_second_time = $mock->arguments(1);
 
-Returns an array reference containing the arugments that were passed to the mocked subroutine (but see also L</store_arguments>).
+Returns an array reference containing the arguments that were passed to the mocked subroutine (but see also L</store_arguments>).
 Optionally an integer may be passed which designates the call number to fetch arguments in the same manner of indexing an array (zero indexed).
 If not given, C<0> is assumed, representing the first time the mock was called.
 Returns C<undef> if the mocked subroutine was not called (or was not called enough times).
@@ -226,6 +226,10 @@ When used as a setter, it returns the mock instance for chaining if desired.
 
 =head2 Run code before the original
 
+The original version of the mocked function (read: the code that was available via the symbol B<at the time the mock was initiated>)
+is available via the fully qualified symbol C<Mock::MonkeyPatch::ORIGINAL>.
+You can call this in your mock if for example you want to do some setup before calling the function.
+
   my $mock = $self->patch($symbol, sub {
     # do some stuff before the original
     do_mocked_stuff(@_);
@@ -233,6 +237,16 @@ When used as a setter, it returns the mock instance for chaining if desired.
     Mock::MonkeyPatch::ORIGINAL(@_);
   });
 
+=head2 Using ORIGINAL in a nonblocking environment
+
+Since the C<ORIGINAL> symbol is implemented via C<local> if you want to call it after leaving the scope you need to store a reference to the function in a lexical.
+
+  my $mock = $self->patch($symbol, sub {
+    my @args = @_;
+    my $orig = \&Mock::MonkeyPatch::ORIGINAL;
+    Mojo::IOLoop->timer(1 => sub { $orig->(@args) });
+  });
+
 =head1 SEE ALSO
 
 =over
@@ -259,9 +273,23 @@ L<http://github.com/jberger/Mock-MonkeyPatch>
 
 Joel Berger, E<lt>joel.a.berger@gmail.comE<gt>
 
+=head1 CONTRIBUTORS
+
+=over 
+
+=item *
+
+Doug Bell (preaction)
+
+=item *
+
+Brian Medley (bpmedley)
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2016 by Joel Berger
+Copyright (C) 2016 by Joel Berger and L</CONTRIBUTORS>
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
